#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

// Define the screen size and the OLED reset pin
#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 64
#define OLED_RESET    -1  // No reset pin needed for SSD1315

// Create an OLED display object
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

// Function to draw open eyes
void drawOpenEyes() {
  display.clearDisplay();
  // Draw two open eyes (represented by circles)
  display.fillEllipse(40, 32, 10, WHITE);  // Left eye
  display.fillEllipse(88, 32, 10, WHITE);  // Right eye
  display.display();
}

// Function to draw closed eyes (simulating a blink)
void drawClosedEyes() {
  display.clearDisplay();
  // Draw two closed eyes (represented by horizontal lines)
  display.fillRect(30, 28, 20, 4, WHITE);  // Left eye closed
  display.fillRect(78, 28, 20, 4, WHITE);  // Right eye closed
  display.display();
}

void setup() {
  // Initialize the display
  if (!display.begin(SSD1306_I2C_ADDRESS, OLED_RESET)) {
    Serial.println(F("SSD1306 allocation failed"));
    for (;;); // Infinite loop if display setup fails
  }

  display.display();  // Initial screen update
  delay(2000);        // Wait for 2 seconds
}

void loop() {
  drawOpenEyes();  // Draw open eyes
  delay(500);      // Wait for 0.5 second

  drawClosedEyes();  // Draw closed eyes (blink)
  delay(200);        // Wait for 0.2 second

  drawOpenEyes();  // Draw open eyes again
  delay(500);      // Wait for 0.5 second
}
